summaryrefslogtreecommitdiffstats
path: root/src/cli.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/cli.rs')
-rw-r--r--src/cli.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/cli.rs b/src/cli.rs
index e9e0323..3e52af9 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -18,9 +18,9 @@ pub struct Cli {
/// Forces the session to be saved
#[clap(long)]
pub save_session: bool,
- /// Start a bot
+ /// Start a agent
#[clap(short = 'b', long)]
- pub bot: Option<String>,
+ pub agent: Option<String>,
/// Start a RAG
#[clap(long)]
pub rag: Option<String>,
@@ -63,9 +63,9 @@ pub struct Cli {
/// List all sessions
#[clap(long)]
pub list_sessions: bool,
/// List all bots
#[clap(long)]
- pub list_bots: bool,
+ pub list_agents: bool,
/// List all RAGs
#[clap(long)]
pub list_rags: bool,
@@ -63,9 +63,9 @@ pub struct Cli {
#[clap(long)]
pub list_sessions: bool,
- /// List all bots
+ /// List all agents
#[clap(long)]